==> delphixpy-1.7.0.0.tar.gz: delphixpy-1.7.0.0/delphixpy/v1_4_3/web/capacity/system/historical/historical.py <==
#
# Copyright 2016 by Delphix
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

"""
Package "capacity.system.historical"
"""
# pylint: disable=W0403,W0611,W0622
API_VERSION = "1.4.3"

import urllib
from delphixpy.v1_4_3 import response_validator

def get_all(engine, start_date=None, end_date=None):
    """
    Lists historical system capacity data.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_4_3.delphix_engine.DelphixEngine`
    :param start_date: Earliest date for which to list data.
    :type start_date: ``basestring``
    :param end_date: Latest date for which to list data.
    :type end_date: ``basestring``
    :rtype: ``list`` of :py:class:`v1_4_3.web.vo.HistoricalSystemCapacityData`
    """
    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
    url = "/resources/json/delphix/capacity/system/historical"
    query_params = {"startDate": start_date, "endDate": end_date}
    query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
    if query_dct:
        url_params = urllib.urlencode(query_dct)
        url += "?%s" % url_params
    response = engine.get(url)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=[u'HistoricalSystemCapacityData'], returns_list=True, raw_result=raw_result)

==> delphixpy-1.8.0.0.tar.gz: delphixpy-1.8.0.0/delphixpy/v1_6_0/web/capacity/system/historical/historical.py <==
#
# Copyright 2016 by Delphix
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

"""
Package "capacity.system.historical"
"""
# pylint: disable=W0403,W0611,W0622
API_VERSION = "1.6.0"

import urllib
from delphixpy.v1_6_0 import response_validator

def get_all(engine, end_date=None, resolution=None, start_date=None):
    """
    Lists historical system capacity data.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_6_0.delphix_engine.DelphixEngine`
    :param end_date: Latest date for which to list data.
    :type end_date: ``basestring``
    :param resolution: The time range each datapoint should represent, measured
        in seconds.
    :type resolution: ``int``
    :param start_date: Earliest date for which to list data.
    :type start_date: ``basestring``
    :rtype: ``list`` of :py:class:`v1_6_0.web.vo.HistoricalSystemCapacityData`
    """
    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
    url = "/resources/json/delphix/capacity/system/historical"
    query_params = {"resolution": resolution, "endDate": end_date, "startDate": start_date}
    query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
    if query_dct:
        url_params = urllib.urlencode(query_dct)
        url += "?%s" % url_params
    response = engine.get(url)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=[u'HistoricalSystemCapacityData'], returns_list=True, raw_result=raw_result)
